==> nextcloud-14.0.1.tgz: nextcloud/apps/files/l10n/sq.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depozita përkohësisht nuk është në dispozicion",
    "Storage invalid" : "Depozitë e pavlefshme",
    "Unknown error" : "Gabim i panjohur",
    "All files" : "Të gjithë skedarët",
    "Recent" : "Të fundit",
    "Favorites" : "Të parapëlqyera",
    "File could not be found" : "Skedari s’u gjet dot",
    "Download" : "Shkarkoje",
    "Delete" : "Fshije",
    "Home" : "Kreu",
    "Close" : "Mbylle",
    "Could not create folder \"{dir}\"" : "S’u krijua dot dosja \"{dir}\"",
    "Upload cancelled." : "Ngarkimi u anulua.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "S’arrihet të ngarkohet {filename}, ngaqë është drejtori ose ka 0 bajte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nuk ka hapësirë të mjaftueshme, po ngarkoni {size1}, por ka vetëm {size2} të lira",
    "Target folder \"{dir}\" does not exist any more" : "Dosja e synuar \"{dir}\" nuk ekziston më",
    "Not enough free space" : "Nuk ka hapsirë të mjaftueshme të lirë",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
    "Actions" : "Veprime",
    "Rename" : "Riemërtojeni",
    "Target folder" : "Dosja e synuar",
    "Disconnect storage" : "Shkëpute depozitën",
    "Unshare" : "Hiqe ndarjen",
    "Could not load info for file \"{file}\"" : "Nuk mund të ngarkohet informacioni për skedarin \"{file}\"",
    "Files" : "Skedar",
    "Details" : "Hollësi",
    "Select" : "Përzgjidhe",
    "Pending" : "Në pritje",
    "Unable to determine date" : "S’arrihet të përcaktohet data",
    "This operation is forbidden" : "Ky veprim është i ndaluar",
    "This directory is unavailable, please check the logs or contact the administrator" : "Kjo drejtori nuk kapet, ju lutemi, kontrolloni regjistrat ose lidhuni me përgjegjësin",
    "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
    "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
    "{newName} already exists" : "{newName} ekziston tashmë",
    "Could not rename \"{fileName}\", it does not exist any more" : "S’u riemërtua dot \"{fileName}\", s’ekziston më",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Emri \"{targetName}\" është tashmë i përdorur te dosja \"{dir}\". Ju lutemi, zgjidhni një emër tjetër.",
    "Could not rename \"{fileName}\"" : "S’u riemërtua dot \"{fileName}\"",
    "Could not create file \"{file}\"" : "S’u krijua dot kartela \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "S’u krijua dot kartela \"{file}\" ngaqë ka një të tillë",
    "Could not create folder \"{dir}\" because it already exists" : "S’u krijua dot dosja \"{dir}\" ngaqë ka një të tillë",
    "Error deleting file \"{fileName}\"." : "Gabim në fshirjen e kartelës \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Asnjë rezultat i kërkimit në dosjet e tjera për {tag} {filter} {endtag}",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më",
    "_%n folder_::_%n folders_" : ["%n dosje","%n dosje"],
    "_%n file_::_%n files_" : ["%n kartelë","%n skedar"],
    "{dirs} and {files}" : "{dirs} dhe {files}",
    "_including %n hidden_::_including %n hidden_" : ["Përfshirë %n të fshehura","Përfshirë %n të fshehura"],
    "You don’t have permission to upload or create files here" : "S’keni leje për të ngarkuar apo krijuar kartela këtu",
    "_Uploading %n file_::_Uploading %n files_" : ["Po ngarkohet %n kartelë","Po ngarkohen %n skedar"],
    "New" : "E re",
    "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nuk është një lloj skedari i lejuar",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Depozita e {owner} është plot, kartelat s’mund të përditësohen ose sinkronizohet më!",
    "Your storage is full, files can not be updated or synced anymore!" : "Depozita juaj është plot, kartelat s’mund të përditësohen ose sinkronizohet më!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Depozita e {owner} është thuasje plot ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depozita juaj është thuajse plot ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ka përputhje me '{filter}'","ka përputhje me '{filter}'"],
    "View in folder" : "Shikoje në dosje",
    "Copied!" : "E kopjuar!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopjo lidhjen e drejtpërdrejtë (funksionon vetëm për përdoruesit që kanë qasje në këtë skedar/dosje)",
    "Path" : "Rrugë",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajte"],
    "Favorited" : "U kalua e parapëlqyer",
    "Favorite" : "E parapëlqyer",
    "New folder" : "Dosje e re",
    "Upload file" : "Ngarko skedar",
    "An error occurred while trying to update the tags" : "Ndodhi një gabim teksa provohej të përditësoheshin etiketat",
    "Added to favorites" : "U shtua te të parapëlqyerat",
    "Removed from favorites" : "U hoq nga të parapëlqyerat",
    "You added {file} to your favorites" : "Ju shtuat {file} te të parapëlqyerat",
    "You removed {file} from your favorites" : "Ju hoqët {file} nga të parapëlqyerat",
    "File changes" : "Ndryshimet në skedar",
    "Created by {user}" : "U krijua nga {user}",
    "Changed by {user}" : "U ndryshua nga {user}",
    "Deleted by {user}" : "U fshi nga {user}",
    "Restored by {user}" : "U rikthye nga {user}",
    "Renamed by {user}" : "U riemërua nga {user}",
    "Moved by {user}" : "U ndryshua nga {user}",
    "\"remote user\"" : "\"përdorues i largët\"",
    "You created {file}" : "Ju krijuat {file}",
    "{user} created {file}" : "{user} krijoj {file}",
    "{file} was created in a public folder" : "{file} u krijua në një folder publik",
    "You changed {file}" : "Ju ndryshuat {file}",
    "{user} changed {file}" : "{user} ndryshoj {file}",
    "You deleted {file}" : "Ju fshit {file}",
    "{user} deleted {file}" : "{user} fshiu {file}",
    "You restored {file}" : "Ju rikthyet {file}",
    "{user} restored {file}" : "{user} riktheu {file}",
    "You renamed {oldfile} to {newfile}" : "Ju riemëruat {oldfile} në {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} riemëruat {oldfile} në {newfile}",
    "You moved {oldfile} to {newfile}" : "Ju lëvizët {oldfile} në {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} lëvizi {oldfile} në {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Një skedar është shtuar ose është hequr nga <strong>të preferuarat</strong> tuaja",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Një skedar ose dosje është <strong>ndryshuar</strong> ose <strong>riemëruar</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>U krijua</strong> një kartelë ose dosje e re",
    "A file or folder has been <strong>deleted</strong>" : "Një skedar ose dosje është <strong> fshirë </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Kufizojini njoftimet mbi krijim dhe ndryshim kartelash vetëm për <strong>kartelat tuaja të parapëlqyera</strong> <em>(Vetëm te rrjedha)</em>",
    "A file or folder has been <strong>restored</strong>" : "Një skedar ose dosje është <strong> rikthyer </strong>",
    "Unlimited" : "E palimituar",
    "Upload (max. %s)" : "Ngarkim (max. %s)",
    "File handling" : "Trajtim kartele",
    "Maximum upload size" : "Madhësi maksimale ngarkimi",
    "max. possible: " : "maks. i mundshëm: ",
    "Save" : "Ruaje",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Me PHP-FPM mund të duhen 5 minuta që ndryshimet të hyjnë në fuqi.",
    "Missing permissions to edit from here." : "Mungojnë lejet për përpunim që nga këtu.",
    "%s of %s used" : "%s nga %s është përdorur",
    "%s used" : "%s të përdorura",
    "Settings" : "Rregullime",
    "Show hidden files" : "Shfaq kartela të fshehura",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Anulo ngarkimin",
    "No files in here" : "S’ka kartela këtu",
    "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
    "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
    "Select all" : "Përzgjidhe krejt",
    "Upload too large" : "Ngarkim shumë i madh",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kartelat që po rrekeni të ngarkoni e tejkalojnë madhësinë maksimale për ngarkime kartelash në këtë shërbyes.",
    "No favorites yet" : "Asnjë preferencë akoma",
    "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
    "Tags" : "Etiketë",
    "Deleted files" : "Skedar të fshirë",
    "Shares" : "Shpërndarjet",
    "Shared with others" : "E ndarë me të tjerët",
    "Shared with you" : "E ndarë me ju",
    "Shared by link" : "E ndarë me lidhje",
    "Deleted shares" : "Fshi shpërndarjet",
    "Text file" : "Kartelë tekst",
    "New text file.txt" : "Kartelë e re file.txt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/files/l10n/sq.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depozita përkohësisht nuk është në dispozicion",
    "Storage invalid" : "Depozitë e pavlefshme",
    "Unknown error" : "Gabim i panjohur",
    "All files" : "Të gjithë skedarët",
    "Recent" : "Të fundit",
    "Favorites" : "Të parapëlqyera",
    "File could not be found" : "Skedari s’u gjet dot",
    "Download" : "Shkarkoje",
    "Delete" : "Fshije",
    "Home" : "Kreu",
    "Close" : "Mbylle",
    "Could not create folder \"{dir}\"" : "S’u krijua dot dosja \"{dir}\"",
    "Upload cancelled." : "Ngarkimi u anulua.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "S’arrihet të ngarkohet {filename}, ngaqë është drejtori ose ka 0 bajte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nuk ka hapësirë të mjaftueshme, po ngarkoni {size1}, por ka vetëm {size2} të lira",
    "Target folder \"{dir}\" does not exist any more" : "Dosja e synuar \"{dir}\" nuk ekziston më",
    "Not enough free space" : "Nuk ka hapsirë të mjaftueshme të lirë",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
    "Actions" : "Veprime",
    "Rename" : "Riemërtojeni",
    "Copy" : "Kopjo",
    "Delete file" : "Fshi skedarin",
    "Delete folder" : "Fshini dosjen",
    "Disconnect storage" : "Shkëpute depozitën",
    "Unshare" : "Hiqe ndarjen",
    "Could not load info for file \"{file}\"" : "Nuk mund të ngarkohet informacioni për skedarin \"{file}\"",
    "Files" : "Skedar",
    "Details" : "Hollësi",
    "Select" : "Përzgjidhe",
    "Pending" : "Në pritje",
    "Unable to determine date" : "S’arrihet të përcaktohet data",
    "This operation is forbidden" : "Ky veprim është i ndaluar",
    "This directory is unavailable, please check the logs or contact the administrator" : "Kjo drejtori nuk kapet, ju lutemi, kontrolloni regjistrat ose lidhuni me përgjegjësin",
    "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
    "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
    "copy" : "kopjo",
    "{newName} already exists" : "{newName} ekziston tashmë",
    "Could not rename \"{fileName}\", it does not exist any more" : "S’u riemërtua dot \"{fileName}\", s’ekziston më",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Emri \"{targetName}\" është tashmë i përdorur te dosja \"{dir}\". Ju lutemi, zgjidhni një emër tjetër.",
    "Could not rename \"{fileName}\"" : "S’u riemërtua dot \"{fileName}\"",
    "Could not create file \"{file}\"" : "S’u krijua dot kartela \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "S’u krijua dot kartela \"{file}\" ngaqë ka një të tillë",
    "Could not create folder \"{dir}\" because it already exists" : "S’u krijua dot dosja \"{dir}\" ngaqë ka një të tillë",
    "Error deleting file \"{fileName}\"." : "Gabim në fshirjen e kartelës \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Asnjë rezultat i kërkimit në dosjet e tjera për {tag} {filter} {endtag}",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më",
    "_%n folder_::_%n folders_" : ["%n dosje","%n dosje"],
    "_%n file_::_%n files_" : ["%n kartelë","%n skedar"],
    "{dirs} and {files}" : "{dirs} dhe {files}",
    "_including %n hidden_::_including %n hidden_" : ["Përfshirë %n të fshehura","Përfshirë %n të fshehura"],
    "You don’t have permission to upload or create files here" : "S’keni leje për të ngarkuar apo krijuar kartela këtu",
    "_Uploading %n file_::_Uploading %n files_" : ["Po ngarkohet %n kartelë","Po ngarkohen %n skedar"],
    "New" : "E re",
    "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nuk është një lloj skedari i lejuar",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Depozita e {owner} është plot, kartelat s’mund të përditësohen ose sinkronizohet më!",
    "Your storage is full, files can not be updated or synced anymore!" : "Depozita juaj është plot, kartelat s’mund të përditësohen ose sinkronizohet më!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Depozita e {owner} është thuasje plot ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depozita juaj është thuajse plot ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ka përputhje me '{filter}'","ka përputhje me '{filter}'"],
    "View in folder" : "Shikoje në dosje",
    "Copied!" : "E kopjuar!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopjo lidhjen e drejtpërdrejtë (funksionon vetëm për përdoruesit që kanë qasje në këtë skedar/dosje)",
    "Path" : "Rrugë",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajte"],
    "Favorited" : "U kalua e parapëlqyer",
    "Favorite" : "E parapëlqyer",
    "New folder" : "Dosje e re",
    "Upload file" : "Ngarko skedar",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Shtoje tek të parapëlqyerat",
    "An error occurred while trying to update the tags" : "Ndodhi një gabim teksa provohej të përditësoheshin etiketat",
    "Added to favorites" : "U shtua te të parapëlqyerat",
    "Removed from favorites" : "U hoq nga të parapëlqyerat",
    "You added {file} to your favorites" : "Ju shtuat {file} te të parapëlqyerat",
    "You removed {file} from your favorites" : "Ju hoqët {file} nga të parapëlqyerat",
    "File changes" : "Ndryshimet në skedar",
    "Created by {user}" : "U krijua nga {user}",
    "Changed by {user}" : "U ndryshua nga {user}",
    "Deleted by {user}" : "U fshi nga {user}",
    "Restored by {user}" : "U rikthye nga {user}",
    "Renamed by {user}" : "U riemërua nga {user}",
    "Moved by {user}" : "U ndryshua nga {user}",
    "\"remote user\"" : "\"përdorues i largët\"",
    "You created {file}" : "Ju krijuat {file}",
    "{user} created {file}" : "{user} krijoj {file}",
    "{file} was created in a public folder" : "{file} u krijua në një folder publik",
    "You changed {file}" : "Ju ndryshuat {file}",
    "{user} changed {file}" : "{user} ndryshoj {file}",
    "You deleted {file}" : "Ju fshit {file}",
    "{user} deleted {file}" : "{user} fshiu {file}",
    "You restored {file}" : "Ju rikthyet {file}",
    "{user} restored {file}" : "{user} riktheu {file}",
    "You renamed {oldfile} to {newfile}" : "Ju riemëruat {oldfile} në {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} riemëruat {oldfile} në {newfile}",
    "You moved {oldfile} to {newfile}" : "Ju lëvizët {oldfile} në {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} lëvizi {oldfile} në {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Një skedar është shtuar ose është hequr nga <strong>të preferuarat</strong> tuaja",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Një skedar ose dosje është <strong>ndryshuar</strong> ose <strong>riemëruar</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>U krijua</strong> një kartelë ose dosje e re",
    "A file or folder has been <strong>deleted</strong>" : "Një skedar ose dosje është <strong> fshirë </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Kufizojini njoftimet mbi krijim dhe ndryshim kartelash vetëm për <strong>kartelat tuaja të parapëlqyera</strong> <em>(Vetëm te rrjedha)</em>",
    "A file or folder has been <strong>restored</strong>" : "Një skedar ose dosje është <strong> rikthyer </strong>",
    "Unlimited" : "E palimituar",
    "Upload (max. %s)" : "Ngarkim (max. %s)",
    "Accept" : "Prano",
    "Change" : "Ndrysho",
    "Tags" : "Etiketë",
    "%s used" : "%s të përdorura",
    "%1$s of %2$s used" : "%1$s e %2$s përdorur",
    "Settings" : "Rregullime",
    "Show hidden files" : "Shfaq kartela të fshehura",
    "WebDAV" : "WebDAV",
    "No files in here" : "S’ka kartela këtu",
    "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
    "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
    "Select all" : "Përzgjidhe krejt",
    "Upload too large" : "Ngarkim shumë i madh",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kartelat që po rrekeni të ngarkoni e tejkalojnë madhësinë maksimale për ngarkime kartelash në këtë shërbyes.",
    "No favorites yet" : "Asnjë preferencë akoma",
    "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
    "Deleted files" : "Skedar të fshirë",
    "Shares" : "Shpërndarjet",
    "Shared with others" : "E ndarë me të tjerët",
    "Shared with you" : "E ndarë me ju",
    "Shared by link" : "E ndarë me lidhje",
    "Deleted shares" : "Fshi shpërndarjet",
    "Text file" : "Kartelë tekst",
    "New text file.txt" : "Kartelë e re file.txt",
    "%s of %s used" : "%s nga %s është përdorur"
},
"nplurals=2; plural=(n != 1);");
